==> estateplat-common-1.1.0-20160822.054947-160-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzDyaq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlTransient;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 抵押权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:24
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_dyaq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzDyaq implements Serializable {
    //权利编号
    @Id
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //抵押不动产类型
    @XmlElement(name = "dybdclx")
    private String dybdclx;
    //抵押人
    @XmlElement(name = "dyr")
    private String dyr;
    //抵押方式
    @XmlElement(name = "dyfs")
    private String dyfs;
    //在建建筑物坐落
    @XmlElement(name = "zjjzwzl")
    private String zjjzwzl;
    //在建建筑物抵押范围
    @XmlElement(name = "zjjzwdyfw")
    private String zjjzwdyfw;
    //被担保主债权数额
    @XmlElement(name = "bdbzzqse")
    private Double bdbzzqse;
    //债务履行起始时间
    @XmlElement(name = "zwlxqssj")
    private Date zwlxqssj;
    //债务履行结束时间
    @XmlElement(name = "zwlxjssj")
    private Date zwlxjssj;
    //最高债权确定事实
    @XmlElement(name = "zgzqqdss")
    private String zgzqqdss;
    //最高债权数额
    @XmlElement(name = "zgzqse")
    private Double zgzqse;
    //注销抵押业务号
    @XmlElement(name = "zxdyywh")
    private String zxdyywh;
    //注销抵押原因
    @XmlElement(name = "zxdyyy")
    private String zxdyyy;
    //注销时间
    @XmlElement(name = "zxsj")
    private Date zxsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //金额种类
    @XmlElement(name = "jezl")
    private String jezl;
    //其他
    @XmlElement(name = "qt")
    private String qt;
    //zwq 分摊土地面积
    @XmlElement(name = "fttdmj")
    private Double fttdmj;
    //zwq 独用土地面积
    @XmlElement(name = "dytdmj")
    private Double dytdmj;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //昆山这边不走土地登记回传土地登记的数据
    private String tdzh;

    //抵押顺位
    @XmlTransient
    private int dysw;
    //评估价格
    @XmlTransient
    private Double pgjg;
    //抵押范围
    @XmlTransient
    private String dyfw;


    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDybdclx() {
        return dybdclx;
    }

    public void setDybdclx(String dybdclx) {
        this.dybdclx = dybdclx;
    }

    public String getDyr() {
        return dyr;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjjzwzl() {
        return zjjzwzl;
    }

    public void setZjjzwzl(String zjjzwzl) {
        this.zjjzwzl = zjjzwzl;
    }

    public String getZjjzwdyfw() {
        return zjjzwdyfw;
    }

    public void setZjjzwdyfw(String zjjzwdyfw) {
        this.zjjzwdyfw = zjjzwdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public Date getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(Date zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public Date getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(Date zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqse() {
        return zgzqse;
    }

    public void setZgzqse(Double zgzqse) {
        this.zgzqse = zgzqse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJezl() {
        return jezl;
    }

    public void setJezl(String jezl) {
        this.jezl = jezl;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public int getDysw() {
        return dysw;
    }

    public void setDysw(int dysw) {
        this.dysw = dysw;
    }

    public Double getPgjg() {
        return pgjg;
    }

    public void setPgjg(Double pgjg) {
        this.pgjg = pgjg;
    }

    public String getDyfw() {
        return dyfw;
    }

    public void setDyfw(String dyfw) {
        this.dyfw = dyfw;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }
}

==> estateplat-common-1.2.3-20180122.055848-20-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzDyaq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlTransient;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 抵押权
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:24
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_dyaq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzDyaq implements Serializable {
    //权利编号
    @Id
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //抵押不动产类型
    @XmlElement(name = "dybdclx")
    private String dybdclx;
    //抵押人
    @XmlElement(name = "dyr")
    private String dyr;
    //抵押方式
    @XmlElement(name = "dyfs")
    private String dyfs;
    //在建建筑物坐落
    @XmlElement(name = "zjjzwzl")
    private String zjjzwzl;
    //在建建筑物抵押范围
    @XmlElement(name = "zjjzwdyfw")
    private String zjjzwdyfw;
    //被担保主债权数额
    @XmlElement(name = "bdbzzqse")
    private Double bdbzzqse;
    //债务履行起始时间
    @XmlElement(name = "zwlxqssj")
    private Date zwlxqssj;
    //债务履行结束时间
    @XmlElement(name = "zwlxjssj")
    private Date zwlxjssj;
    //最高债权确定事实
    @XmlElement(name = "zgzqqdss")
    private String zgzqqdss;
    //最高债权数额
    @XmlElement(name = "zgzqse")
    private Double zgzqse;
    //注销抵押业务号
    @XmlElement(name = "zxdyywh")
    private String zxdyywh;
    //注销抵押原因
    @XmlElement(name = "zxdyyy")
    private String zxdyyy;
    //注销时间
    @XmlElement(name = "zxsj")
    private Date zxsj;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //金额种类
    @XmlElement(name = "jezl")
    private String jezl;
    //其他
    @XmlElement(name = "qt")
    private String qt;
    //zwq 分摊土地面积
    @XmlElement(name = "fttdmj")
    private Double fttdmj;
    //zwq 独用土地面积
    @XmlElement(name = "dytdmj")
    private Double dytdmj;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //昆山这边不走土地登记回传土地登记的数据
    private String tdzh;

    //抵押顺位
    @XmlTransient
    private int dysw;
    //评估价格
    @XmlTransient
    private Double pgjg;
    //抵押范围
    @XmlTransient
    private String dyfw;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getDybdclx() {
        return dybdclx;
    }

    public void setDybdclx(String dybdclx) {
        this.dybdclx = dybdclx;
    }

    public String getDyr() {
        return dyr;
    }

    public void setDyr(String dyr) {
        this.dyr = dyr;
    }

    public String getDyfs() {
        return dyfs;
    }

    public void setDyfs(String dyfs) {
        this.dyfs = dyfs;
    }

    public String getZjjzwzl() {
        return zjjzwzl;
    }

    public void setZjjzwzl(String zjjzwzl) {
        this.zjjzwzl = zjjzwzl;
    }

    public String getZjjzwdyfw() {
        return zjjzwdyfw;
    }

    public void setZjjzwdyfw(String zjjzwdyfw) {
        this.zjjzwdyfw = zjjzwdyfw;
    }

    public Double getBdbzzqse() {
        return bdbzzqse;
    }

    public void setBdbzzqse(Double bdbzzqse) {
        this.bdbzzqse = bdbzzqse;
    }

    public Date getZwlxqssj() {
        return zwlxqssj;
    }

    public void setZwlxqssj(Date zwlxqssj) {
        this.zwlxqssj = zwlxqssj;
    }

    public Date getZwlxjssj() {
        return zwlxjssj;
    }

    public void setZwlxjssj(Date zwlxjssj) {
        this.zwlxjssj = zwlxjssj;
    }

    public String getZgzqqdss() {
        return zgzqqdss;
    }

    public void setZgzqqdss(String zgzqqdss) {
        this.zgzqqdss = zgzqqdss;
    }

    public Double getZgzqse() {
        return zgzqse;
    }

    public void setZgzqse(Double zgzqse) {
        this.zgzqse = zgzqse;
    }

    public String getZxdyywh() {
        return zxdyywh;
    }

    public void setZxdyywh(String zxdyywh) {
        this.zxdyywh = zxdyywh;
    }

    public String getZxdyyy() {
        return zxdyyy;
    }

    public void setZxdyyy(String zxdyyy) {
        this.zxdyyy = zxdyyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getJezl() {
        return jezl;
    }

    public void setJezl(String jezl) {
        this.jezl = jezl;
    }

    public String getQt() {
        return qt;
    }

    public void setQt(String qt) {
        this.qt = qt;
    }

    public int getDysw() {
        return dysw;
    }

    public void setDysw(int dysw) {
        this.dysw = dysw;
    }

    public Double getPgjg() {
        return pgjg;
    }

    public void setPgjg(Double pgjg) {
        this.pgjg = pgjg;
    }

    public String getDyfw() {
        return dyfw;
    }

    public void setDyfw(String dyfw) {
        this.dyfw = dyfw;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }

    public String getTdzh() {
        return tdzh;
    }

    public void setTdzh(String tdzh) {
        this.tdzh = tdzh;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }
}
